# -*- coding: UTF-8 -*-
# -*- Mode: Python; py-indent-offset: 4 -*-
# Authors: Nik Kim <fafhrd@legco.biz>
"""
$Id: BaseSchedulingTask.py,v 1.5 2004/03/16 05:04:12 fafhrd91 Exp $
"""

from ExtensionClass import Base
from Acquisition import aq_base, aq_acquire
from Globals import InitializeClass
from AccessControl import Permissions
from AccessControl import ClassSecurityInfo

from permissions import ManageSchedulingTask
from Products.ZopeScheduler.ISchedulingTask import ISchedulingTask

class BaseSchedulingTask(Base):

    __implements__ = (ISchedulingTask,)

    _minute = ()
    _hour = ()
    _dom = ()
    _dow = ()
    _month = ()

    security = ClassSecurityInfo()

    security.declareProtected(Permissions.view, 'getSchedulingTime')
    def getSchedulingTime(self, format='tuple'):
        """ """
        return {'minute': self._minute,
                'hour': self._hour,
                'dom': self._dom,
                'dow': self._dow,
                'month': self._month}

    security.declareProtected(ManageSchedulingTask, 'setSchedulingTime')
    def setSchedulingTime(self, minute=[], hour=[], dom=[], dow=[], month=[]):
        """ """
        self._minute = [int(s) for s in minute]
        self._hour = [int(s) for s in hour]
        self._dom = [int(s) for s in dom]
        self._dow = [int(s) for s in dow]
        self._month = [int(s) for s in month]

    security.declareProtected(Permissions.view, 'isSchedulerActive')
    def isSchedulerActive(self):
        """ """
        try:
            return self.getScheduler().isRegisteredTask('/'.join(self.getPhysicalPath()))
        except:
            return 0

    security.declarePrivate('getScheduler')
    def getScheduler(self):
        return aq_acquire(self, 'zope_scheduler', containment=1)

    security.declareProtected(ManageSchedulingTask, 'activateScheduler')
    def activateScheduler(self):
        """ """
        scheduler = self.getScheduler()
        if scheduler is not None:
            d = self.getSchedulingTime('dict')
            scheduler.registerTask('/'.join(self.getPhysicalPath()), **d)

    security.declareProtected(ManageSchedulingTask, 'deactivateScheduler')
    def deactivateScheduler(self):
        """ """
        scheduler = self.getScheduler()
        if scheduler is not None:
            scheduler.unregisterTask('/'.join(self.getPhysicalPath()))
        
    security.declareProtected(Permissions.view, 'isSchedulerAvailable')
    def isSchedulerAvailable(self):
        """ checks if Zope Scheduler available """
        scheduler = self.getScheduler()
        return scheduler is not None

    # ISchedulingTask interface
    security.declarePrivate('process_task')
    def process_task(self):
        raise NotImplementedError


InitializeClass(BaseSchedulingTask)


try:
    from Products.CMFCore.utils import getToolByName

    class CMFSchedulingTask(BaseSchedulingTask):

        security = ClassSecurityInfo()
        
        security.declarePrivate('getScheduler')
        def getScheduler(self):
            return getToolByName(self, 'zope_scheduler', None)

except ImportError:

    class CMFSchedulingTask(BaseSchedulingTask):
        pass

InitializeClass(BaseSchedulingTask)
